EXPORTS
	??1CMMFDevSound@@UAE@XZ @ 1 NONAME ; public: virtual __thiscall CMMFDevSound::~CMMFDevSound(void)
	?Capabilities@CMMFDevSound@@QAE?AVTMMFCapabilities@@XZ @ 2 NONAME ; public: class TMMFCapabilities  __thiscall CMMFDevSound::Capabilities(void)
	?Config@CMMFDevSound@@QBE?AVTMMFCapabilities@@XZ @ 3 NONAME ; public: class TMMFCapabilities  __thiscall CMMFDevSound::Config(void)const 
	?CustomInterface@CMMFDevSound@@QAEPAXVTUid@@@Z @ 4 NONAME ; public: void * __thiscall CMMFDevSound::CustomInterface(class TUid)
	?E32Dll@@YAHW4TDllReason@@@Z @ 5 NONAME ; int __cdecl E32Dll(enum TDllReason)
	?FixedSequenceCount@CMMFDevSound@@QAEHXZ @ 6 NONAME ; public: int __thiscall CMMFDevSound::FixedSequenceCount(void)
	?FixedSequenceName@CMMFDevSound@@QAEABVTDesC16@@H@Z @ 7 NONAME ; public: class TDesC16 const & __thiscall CMMFDevSound::FixedSequenceName(int)
	?Gain@CMMFDevSound@@QAEHXZ @ 8 NONAME ; public: int __thiscall CMMFDevSound::Gain(void)
	?GetPlayBalanceL@CMMFDevSound@@QAEXAAH0@Z @ 9 NONAME ; public: void __thiscall CMMFDevSound::GetPlayBalanceL(int &,int &)
	?GetRecordBalanceL@CMMFDevSound@@QAEXAAH0@Z @ 10 NONAME ; public: void __thiscall CMMFDevSound::GetRecordBalanceL(int &,int &)
	?InitializeL@CMMFDevSound@@QAEXAAVMDevSoundObserver@@W4TMMFState@@@Z @ 11 NONAME ; public: void __thiscall CMMFDevSound::InitializeL(class MDevSoundObserver &,enum TMMFState)
	?InitializeL@CMMFDevSound@@QAEXAAVMDevSoundObserver@@VTFourCC@@W4TMMFState@@@Z @ 12 NONAME ; public: void __thiscall CMMFDevSound::InitializeL(class MDevSoundObserver &,class TFourCC,enum TMMFState)
	?InitializeL@CMMFDevSound@@QAEXAAVMDevSoundObserver@@VTUid@@W4TMMFState@@@Z @ 13 NONAME ; public: void __thiscall CMMFDevSound::InitializeL(class MDevSoundObserver &,class TUid,enum TMMFState)
	?MaxGain@CMMFDevSound@@QAEHXZ @ 14 NONAME ; public: int __thiscall CMMFDevSound::MaxGain(void)
	?MaxVolume@CMMFDevSound@@QAEHXZ @ 15 NONAME ; public: int __thiscall CMMFDevSound::MaxVolume(void)
	?NewL@CMMFDevSound@@SAPAV1@XZ @ 16 NONAME ; public: static class CMMFDevSound * __cdecl CMMFDevSound::NewL(void)
	?NewL@CMMFDevSoundEventHandler@@SAPAV1@PAVRMMFAudioPolicyProxy@@@Z @ 17 NONAME ; public: static class CMMFDevSoundEventHandler * __cdecl CMMFDevSoundEventHandler::NewL(class RMMFAudioPolicyProxy *)
	?Pause@CMMFDevSound@@QAEXXZ @ 18 NONAME ; public: void __thiscall CMMFDevSound::Pause(void)
	?PlayDTMFStringL@CMMFDevSound@@QAEXABVTDesC16@@@Z @ 19 NONAME ; public: void __thiscall CMMFDevSound::PlayDTMFStringL(class TDesC16 const &)
	?PlayData@CMMFDevSound@@QAEXXZ @ 20 NONAME ; public: void __thiscall CMMFDevSound::PlayData(void)
	?PlayFixedSequenceL@CMMFDevSound@@QAEXH@Z @ 21 NONAME ; public: void __thiscall CMMFDevSound::PlayFixedSequenceL(int)
	?PlayInitL@CMMFDevSound@@QAEXXZ @ 22 NONAME ; public: void __thiscall CMMFDevSound::PlayInitL(void)
	?PlayToneL@CMMFDevSound@@QAEXHABVTTimeIntervalMicroSeconds@@@Z @ 23 NONAME ; public: void __thiscall CMMFDevSound::PlayToneL(int,class TTimeIntervalMicroSeconds const &)
	?PlayToneSequenceL@CMMFDevSound@@QAEXABVTDesC8@@@Z @ 24 NONAME ; public: void __thiscall CMMFDevSound::PlayToneSequenceL(class TDesC8 const &)
	?RecordData@CMMFDevSound@@QAEXXZ @ 25 NONAME ; public: void __thiscall CMMFDevSound::RecordData(void)
	?RecordInitL@CMMFDevSound@@QAEXXZ @ 26 NONAME ; public: void __thiscall CMMFDevSound::RecordInitL(void)
	?SamplesPlayed@CMMFDevSound@@QAEHXZ @ 27 NONAME ; public: int __thiscall CMMFDevSound::SamplesPlayed(void)
	?SamplesRecorded@CMMFDevSound@@QAEHXZ @ 28 NONAME ; public: int __thiscall CMMFDevSound::SamplesRecorded(void)
	?SetConfigL@CMMFDevSound@@QAEXABVTMMFCapabilities@@@Z @ 29 NONAME ; public: void __thiscall CMMFDevSound::SetConfigL(class TMMFCapabilities const &)
	?SetDTMFLengths@CMMFDevSound@@QAEXAAVTTimeIntervalMicroSeconds32@@00@Z @ 30 NONAME ; public: void __thiscall CMMFDevSound::SetDTMFLengths(class TTimeIntervalMicroSeconds32 &,class TTimeIntervalMicroSeconds32 &,class TTimeIntervalMicroSeconds32 &)
	?SetGain@CMMFDevSound@@QAEXH@Z @ 31 NONAME ; public: void __thiscall CMMFDevSound::SetGain(int)
	?SetPlayBalanceL@CMMFDevSound@@QAEXHH@Z @ 32 NONAME ; public: void __thiscall CMMFDevSound::SetPlayBalanceL(int,int)
	?SetPrioritySettings@CMMFDevSound@@QAEXABVTMMFPrioritySettings@@@Z @ 33 NONAME ; public: void __thiscall CMMFDevSound::SetPrioritySettings(class TMMFPrioritySettings const &)
	?SetRecordBalanceL@CMMFDevSound@@QAEXHH@Z @ 34 NONAME ; public: void __thiscall CMMFDevSound::SetRecordBalanceL(int,int)
	?SetToneRepeats@CMMFDevSound@@QAEXHABVTTimeIntervalMicroSeconds@@@Z @ 35 NONAME ; public: void __thiscall CMMFDevSound::SetToneRepeats(int,class TTimeIntervalMicroSeconds const &)
	?SetVolume@CMMFDevSound@@QAEXH@Z @ 36 NONAME ; public: void __thiscall CMMFDevSound::SetVolume(int)
	?SetVolumeRamp@CMMFDevSound@@QAEXABVTTimeIntervalMicroSeconds@@@Z @ 37 NONAME ; public: void __thiscall CMMFDevSound::SetVolumeRamp(class TTimeIntervalMicroSeconds const &)
	?Stop@CMMFDevSound@@QAEXXZ @ 38 NONAME ; public: void __thiscall CMMFDevSound::Stop(void)
	?Volume@CMMFDevSound@@QAEHXZ @ 39 NONAME ; public: int __thiscall CMMFDevSound::Volume(void)
	?PlayDualToneL@CMMFDevSound@@QAEXHHABVTTimeIntervalMicroSeconds@@@Z @ 40 NONAME ; public: void __thiscall CMMFDevSound::PlayDualToneL(int,int,class TTimeIntervalMicroSeconds const &)
	?GetSupportedInputDataTypesL@CMMFDevSound@@QBEXAAV?$RArray@VTFourCC@@@@ABVTMMFPrioritySettings@@@Z @ 41 NONAME ; public: void __thiscall CMMFDevSound::GetSupportedInputDataTypesL(class RArray<class TFourCC> &,class TMMFPrioritySettings const &)const 
	?GetSupportedOutputDataTypesL@CMMFDevSound@@QBEXAAV?$RArray@VTFourCC@@@@ABVTMMFPrioritySettings@@@Z @ 42 NONAME ; public: void __thiscall CMMFDevSound::GetSupportedOutputDataTypesL(class RArray<class TFourCC> &,class TMMFPrioritySettings const &)const

